@@ -1,14 +1,18 @@
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
+# copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: route.tcl,v 1.5 1998/12/20 16:47:06 jfontain Exp $}
+set rcsId {$Id: route.tcl,v 1.7 1998/12/26 16:43:01 jfontain Exp $}
 
-package provide route 1.0
+package provide route 1.1
 
-package require network
+package require network 1.2
 
 namespace eval route {
 
+    if {[info exists ::env(MOODSSREMOTE)]} {                                                                    ;# remote monitoring
+        foreach {remote(user) remote(host)} [network::parseRemoteLocator $::env(MOODSSREMOTE)] {}
+    }
+
     array set data {
         updates 0
         0,label interface 0,type ascii 0,message {networking interface}
@@ -19,25 +23,42 @@ namespace eval route {
         5,label references 5,type integer 5,message {number of references to the route}
         6,label use 6,type integer 6,message {count of lookups for the route}
         7,label metric 7,type integer 7,message {distance (in hops) to the target}
-        pollTimes {20 10 30 60 120 300 600}
         sort {1 increasing}
         helpText {
 This is a view of network routes for the system (tested on IPv4 only).
 Networks and hosts addresses are looked up and converted to official names when possible.
+
+For remote monitoring (rsh facilities must be properly setup), set the environment variable MOODSSREMOTE to user@host or simply host for use with current user name.
         }
     }
 
-    set file [open /proc/net/route]                                                     ;# keep the file open for better performance
+    if {[info exists remote]} {
+        set data(pollTimes) {20 10 30 60 120 300 600}                                    ;# poll less often when remotely monitoring
+    } else {
+        set data(pollTimes) {10 5 20 30 60 120 300 600}
+    }
+
+    if {[info exists remote]&&[catch "exec /usr/bin/rsh -l $remote(user) $remote(host) stat /proc/net/route" message]} {
+        puts stderr "on host $remote(host) as user $remote(user), file error: $message"                       ;# detect errors early
+        exit 1
+    } else {
+        set file [open /proc/net/route]                                               ;# keep local file open for better performance
+    }
 
     set nextIndex 0
 
     proc update {} {
+        variable remote
         variable file
         variable index
         variable nextIndex
         variable data
 
-        seek $file 0                                                                                ;# rewind before retrieving data
+        if {[info exists remote]} {
+            set file [open "| /usr/bin/rsh -l $remote(user) $remote(host) cat /proc/net/route"]
+        } else {
+            seek $file 0                                                                            ;# rewind before retrieving data
+        }
         gets $file                                                                                               ;# skip header line
         while {[gets $file line]>=0} {
             scan $line {%s %2x%2x%2x%2x %2x%2x%2x%2x %x %u %u %u %2x%2x%2x%2x}\
@@ -70,6 +91,9 @@ Networks and hosts addresses are looked up and converted to official names when
             set data($row,7) $metric
             set current($address) {}
         }
+        if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
+            close $file
+        }
         foreach address [array names index] {                                                         ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
             set row $index($address)
